==> pyglossary_4.5.0.orig.tar.gz: pyglossary-4.5.0/doc/p/dict_org_source.md <==
## DICT.org dictfmt source file

### General Information

| Attribute       | Value                                              |
| --------------- | -------------------------------------------------- |
| Name            | DictOrgSource                                      |
| snake_case_name | dict_org_source                                    |
| Description     | DICT.org dictfmt source file                       |
| Extensions      | `.dtxt`                                            |
| Read support    | No                                                 |
| Write support   | Yes                                                |
| Single-file     | Yes                                                |
| Kind            | 📝 text                                             |
| Sort-on-write   | default_no                                         |
| Sort key        | (`headword_lower`)                                 |
| Wiki            | [DICT](https://en.wikipedia.org/wiki/DICT)         |
| Website         | [@cheusov/dictd](https://github.com/cheusov/dictd) |

### Write options

| Name            | Default | Type | Comment              |
| --------------- | ------- | ---- | -------------------- |
| remove_html_all | `True`  | bool | Remove all HTML tags |



### Dictionary Applications/Tools

| Name & Website                                 | License | Platforms |
| ---------------------------------------------- | ------- | --------- |
| [dictfmt](https://linux.die.net/man/1/dictfmt) | GPL     | Linux     |

==> pyglossary_5.0.9.orig.tar.gz: pyglossary-5.0.9/doc/p/dict_org_source.md <==
## DICT.org dictfmt source file

### General Information

| Attribute       | Value                                              |
| --------------- | -------------------------------------------------- |
| Name            | DictOrgSource                                      |
| snake_case_name | dict_org_source                                    |
| Description     | DICT.org dictfmt source file                       |
| Extensions      | `.dtxt`                                            |
| Read support    | No                                                 |
| Write support   | Yes                                                |
| Single-file     | Yes                                                |
| Kind            | 📝 text                                             |
| Sort-on-write   | No (by default)                                    |
| Sort key        | (`headword_lower`)                                 |
| Wiki            | [DICT](https://en.wikipedia.org/wiki/DICT)         |
| Website         | [@cheusov/dictd](https://github.com/cheusov/dictd) |

### Write options

| Name            | Default | Type | Comment              |
| --------------- | ------- | ---- | -------------------- |
| remove_html_all | `True`  | bool | Remove all HTML tags |

### Dictionary Applications/Tools

| Name & Website                                 | Source code | License | Platforms | Language |
| ---------------------------------------------- | ----------- | ------- | --------- | -------- |
| [dictfmt](https://linux.die.net/man/1/dictfmt) | ―           | GPL     | Linux     |          |
